@@ -12,7 +12,8 @@
 
 #include <AkonadiCore/Attribute>
 
-namespace NoteShared {
+namespace NoteShared
+{
 class NOTESHARED_EXPORT NoteLockAttribute : public Akonadi::Attribute
 {
 public:
