@@ -21,12 +21,14 @@
 class KNote;
 class KNoteFindDialog;
 class KNotesAkonadiTray;
-namespace NoteShared {
+namespace NoteShared
+{
 class NotesChangeRecorder;
 class NotesAkonadiTreeModel;
 }
 
-namespace KDNSSD {
+namespace KDNSSD
+{
 class PublicService;
 }
 
@@ -37,7 +39,7 @@ class KNotesApp : public QWidget, virtual public KXMLGUIClient
     Q_OBJECT
 public:
     explicit KNotesApp(QWidget *parent = nullptr);
-    ~KNotesApp();
+    ~KNotesApp() override;
 
     Q_REQUIRED_RESULT QString name(Akonadi::Item::Id id) const;
     Q_REQUIRED_RESULT QString text(Akonadi::Item::Id id) const;
@@ -79,6 +81,7 @@ private Q_SLOTS:
     void slotDeleteSelectedNotes();
 
     void newNoteFromTextFile();
+
 private:
     void saveNotes(bool force = false, bool sync = false);
     void updateNetworkListener();
