@@ -1,17 +1,18 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef KNOTEEDITORCONFIGWIDGET_H
 #define KNOTEEDITORCONFIGWIDGET_H
 
-#include <QWidget>
 #include "knotes_export.h"
+#include <QWidget>
 class QSpinBox;
 class QCheckBox;
 class KFontRequester;
-namespace NoteShared {
+namespace NoteShared
+{
 class NoteDisplayAttribute;
 }
 
@@ -20,7 +21,7 @@ class KNOTES_EXPORT KNoteEditorConfigWidget : public QWidget
     Q_OBJECT
 public:
     explicit KNoteEditorConfigWidget(QWidget *parent = nullptr);
-    ~KNoteEditorConfigWidget();
+    ~KNoteEditorConfigWidget() override;
 
     void load(NoteShared::NoteDisplayAttribute *attr, bool isRichText);
     void save(NoteShared::NoteDisplayAttribute *attr, bool &isRichText);
