@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,7 +13,7 @@ class KNotesKeyDialog : public QDialog
 {
 public:
     explicit KNotesKeyDialog(KActionCollection *globals, QWidget *parent);
-    ~KNotesKeyDialog();
+    ~KNotesKeyDialog() override;
 
     void insert(KActionCollection *actions);
 
