@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -11,10 +11,10 @@
 
 #include <AkonadiWidgets/ETMViewStateSaver>
 
+#include "knotes_kontact_plugin_debug.h"
 #include <KAboutData>
 #include <KAcceleratorManager>
 #include <KCheckableProxyModel>
-#include "knotes_kontact_plugin_debug.h"
 #include <KLocalizedString>
 #include <KSharedConfig>
 
@@ -22,8 +22,7 @@
 #include <QTreeView>
 #include <QVBoxLayout>
 
-extern "C"
-{
+extern "C" {
 Q_DECL_EXPORT KCModule *create_knotessummary(QWidget *parent, const char *)
 {
     return new KCMKNotesSummary(parent);
@@ -35,8 +34,7 @@ KCMKNotesSummary::KCMKNotesSummary(QWidget *parent)
 {
     initGUI();
 
-    connect(mCheckedCollectionWidget->folderTreeView(), &QAbstractItemView::clicked,
-            this, &KCMKNotesSummary::modified);
+    connect(mCheckedCollectionWidget->folderTreeView(), &QAbstractItemView::clicked, this, &KCMKNotesSummary::modified);
 
     KAcceleratorManager::manage(this);
 
@@ -47,7 +45,7 @@ KCMKNotesSummary::KCMKNotesSummary(QWidget *parent)
                                        QString(),
                                        i18n("Notes Summary Configuration Dialog"),
                                        KAboutLicense::GPL,
-                                       i18n("Copyright © 2013-2020 Laurent Montel <montel@kde.org>"));
+                                       i18n("Copyright © 2013-2021 Laurent Montel <montel@kde.org>"));
     about->addAuthor(ki18n("Laurent Montel").toString(), QString(), QStringLiteral("montel@kde.org"));
     setAboutData(about);
 }
@@ -59,7 +57,7 @@ void KCMKNotesSummary::modified()
 
 void KCMKNotesSummary::initGUI()
 {
-    auto *layout = new QVBoxLayout(this);
+    auto layout = new QVBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
 
     mCheckedCollectionWidget = new PimCommon::CheckedCollectionWidget(Akonadi::NoteUtils::noteMimeType());
@@ -70,8 +68,7 @@ void KCMKNotesSummary::initFolders()
 {
     KSharedConfigPtr _config = KSharedConfig::openConfig(QStringLiteral("kcmknotessummaryrc"));
 
-    mModelState
-        = new KViewStateMaintainer<Akonadi::ETMViewStateSaver>(_config->group("CheckState"), this);
+    mModelState = new KViewStateMaintainer<Akonadi::ETMViewStateSaver>(_config->group("CheckState"), this);
     mModelState->setSelectionModel(mCheckedCollectionWidget->selectionModel());
 }
 
