@@ -1,13 +1,13 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef KNOTESEDITDIALOG_H
 #define KNOTESEDITDIALOG_H
 
-#include <QDialog>
 #include <KXMLGUIClient>
+#include <QDialog>
 
 class KNoteEdit;
 class KToolBar;
@@ -18,7 +18,7 @@ class KNoteEditDialog : public QDialog, virtual public KXMLGUIClient
     Q_OBJECT
 public:
     explicit KNoteEditDialog(bool readOnly, QWidget *parent = nullptr);
-    ~KNoteEditDialog();
+    ~KNoteEditDialog() override;
 
     void setAcceptRichText(bool b);
     QString text() const;
