@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,7 +12,7 @@
 KNotesWidget::KNotesWidget(KNotesPart *part, QWidget *parent)
     : QWidget(parent)
 {
-    auto *lay = new QVBoxLayout(this);
+    auto lay = new QVBoxLayout(this);
     mSearchLine = new KNotesListWidgetSearchLine;
     lay->addWidget(mSearchLine);
     mIconView = new KNotesIconView(part, parent);
