@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,7 +15,7 @@ class KNotesWidget : public QWidget
     Q_OBJECT
 public:
     explicit KNotesWidget(KNotesPart *part, QWidget *parent = nullptr);
-    ~KNotesWidget();
+    ~KNotesWidget() override;
 
     KNotesIconView *notesView() const;
 
