@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,8 +7,8 @@
 #ifndef KNOTEPRINTSELECTEDNOTESDIALOG_H
 #define KNOTEPRINTSELECTEDNOTESDIALOG_H
 
-#include <QDialog>
 #include <AkonadiCore/Item>
+#include <QDialog>
 class QListWidget;
 class KNote;
 class KNotePrintObject;
@@ -20,7 +20,7 @@ class KNotePrintSelectedNotesDialog : public QDialog
     Q_OBJECT
 public:
     explicit KNotePrintSelectedNotesDialog(QWidget *parent = nullptr);
-    ~KNotePrintSelectedNotesDialog();
+    ~KNotePrintSelectedNotesDialog() override;
 
     void setNotes(const QHash<Akonadi::Item::Id, KNote *> &notes);
 
@@ -34,9 +34,7 @@ private Q_SLOTS:
     void slotSelectionChanged();
 
 private:
-    enum listViewData {
-        AkonadiId = Qt::UserRole + 1
-    };
+    enum listViewData { AkonadiId = Qt::UserRole + 1 };
 
     void writeConfig();
     void readConfig();
