@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,7 +9,8 @@
 #include "knotes_export.h"
 #include <AkonadiCore/Item>
 
-namespace KNoteUtils {
+namespace KNoteUtils
+{
 KNOTES_EXPORT void setDefaultValue(Akonadi::Item &item);
 KNOTES_EXPORT void updateConfiguration();
 }
